<?php

namespace Gear\Auth;

use Firebase\JWT\JWT;

/**
 *  Wrapper for Firebase JWT
 *
 *
 *
 *  @author Björn Hase
 *  @license http://opensource.org/licenses/MIT The MIT License
 *  @link https://gitlab.tentakelfabrik.de/gear/gear-jwt
 */
class Jwt
{
    /**
     *
     *  @param string $secret
     *  @param string $url
     *  @param string $expiredAt
     */
    public function __construct($secret, $url, $expiredAt)
    {
        $this->secret = $secret;
        $this->url = $url;
        $this->expiredAt = $expiredAt;
    }

    /**
     *  encode JWT, adding Data
     *
     *  @param  array $data
     *  @return object
     */
    public function encode($data = NULL)
    {
        // current time
        $time = time();

        // create token
        $token = array(
            'iss' => $this->url,
            'iat' => $time,
            'nbf' => $time,
            'exp' => $time + $this->expiredAt
        );

        if ($data) {
            $token['data'] = $data;
        }

        return JWT::encode($token, $this->secret);
    }

    /**
     *  decode JWT
     *
     *  @param  string $token
     *  @return array
     */
    public function decode($token)
    {
        return JWT::decode($token, $this->secret, array('HS256'));
    }
}
