<?php

namespace Gear\Auth\Middleware;

use Gear/FlightAbstract;

/**
 *  Abstract AuthMiddleware for Flight
 *
 *  @author Björn Hase
 *  @license http://opensource.org/licenses/MIT The MIT License
 *  @link https://gitlab.tentakelfabrik.de/gear/gear-jwt
 */
abstract class AuthMiddlewareAbstract extends FlightAbstract implements AuthInterface
{
    /** routes that are allowed and have not to authenficate */
    protected $allowed = [];

    /** result of attempt */
    protected $result = false;

    /**
     *
     *
     *  @param array $allowed
     */
    public function __construct($allowed)
    {
        parent::__construct();
        $this->allowed = $allowed;
    }

    /**
     *  attempt
     *
     *
     *  @return mixed
     */
    public function attempt()
    {
        $match = NULL;

        // search for pattern if route
        foreach($this->app->router()->getRoutes() as $route) {
            if ($route->matchUrl($this->app->request()->url)) {
                $match = $route;
                break;
            }
        }

        // if pattern is not in the allowed, get HTTP_AUTHORIZATION and parse bearer-token
        if (!in_array($match->pattern, $this->routes)) {
            if (isset($_SERVER['HTTP_AUTHORIZATION']) || isset($_SERVER['REDIRECT_HTTP_AUTHORIZATION'])) {

                if (isset($_SERVER['HTTP_AUTHORIZATION'])) {
                    $header = $_SERVER['HTTP_AUTHORIZATION'];
                }

                if (isset($_SERVER['REDIRECT_HTTP_AUTHORIZATION'])) {
                    $header = $_SERVER['REDIRECT_HTTP_AUTHORIZATION'];
                }

                $token = trim(preg_replace('/^(?:\s+)?Bearer\s/', '', $header));
                $this->check($token);
            }
        }

        // if route not found, set $result to true
        if (!$match) {
            $this->result = true;
        }

        return $this->result;
    }
}
